Type: Package
Package: retroharmonize
Title: Ex Post Survey Data Harmonization
Version: 0.2.8
Date: 2026-05-19
Authors@R: c(
    person(given = "Daniel", 
           family = "Antal", 
           email = "daniel.antal@dataobservatory.eu",
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-7513-6760")),
      person(given = "Marta",
             family = "Kolczynska",
             role = c("ctb"),
             email = "mkolczynska@gmail.com",
             comment = c(ORCID = "0000-0003-4981-0437"))
      )
Maintainer: Daniel Antal <daniel.antal@dataobservatory.eu>
Description: Assist in reproducible retrospective (ex-post) harmonization
    of data, particularly individual level survey data, by providing tools
    for organizing metadata, standardizing the coding of variables, and
    variable names and value labels, including missing values, and
    documenting the data transformations, with the help of comprehensive
    s3 classes.
License: GPL-3
URL: https://retroharmonize.dataobservatory.eu/
BugReports: https://github.com/dataobservatory-eu/retroharmonize/issues
Depends: R (>= 3.5.0)
Imports: assertthat, cli, dataset, dplyr (>= 1.0.0), fs, glue, haven,
        here, labelled, magrittr, purrr, rlang, snakecase, stats,
        stringr, tibble, tidyr, tidyselect, utils, vctrs
Suggests: covr, ggplot2, knitr, markdown, png, rmarkdown, pillar,
        spelling, statcodelists, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-20 19:04:59 UTC; DanielAntal
Author: Daniel Antal [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7513-6760>),
  Marta Kolczynska [ctb] (ORCID: <https://orcid.org/0000-0003-4981-0437>)
Repository: CRAN
Date/Publication: 2026-05-21 07:20:09 UTC
Built: R 4.5.2; ; 2026-05-25 02:35:21 UTC; unix
