# Generated by roxygen2: do not edit by hand

S3method("[",retroharmonize_labelled_spss_survey)
S3method("names<-",retroharmonize_labelled_spss_survey)
S3method(format,retroharmonize_labelled_spss_survey)
S3method(is.na,retroharmonize_labelled_spss_survey)
S3method(levels,retroharmonize_labelled_spss_survey)
S3method(mean,retroharmonize_labelled_spss_survey)
S3method(median,retroharmonize_labelled_spss_survey)
S3method(obj_print_footer,retroharmonize_labelled_spss_survey)
S3method(obj_print_header,retroharmonize_labelled_spss_survey)
S3method(print,retroharmonize_labelled_spss_survey)
S3method(print,survey_df)
S3method(quantile,retroharmonize_labelled_spss_survey)
S3method(sum,retroharmonize_labelled_spss_survey)
S3method(summary,retroharmonize_labelled_spss_survey)
S3method(summary,survey)
S3method(vec_cast,character.retroharmonize_labelled_spss_survey)
S3method(vec_cast,double.retroharmonize_labelled_spss_survey)
S3method(vec_cast,integer.retroharmonize_labelled_spss_survey)
S3method(vec_cast,retroharmonize_labelled_spss_survey.retroharmonize_labelled_spss_survey)
S3method(vec_ptype2,double.retroharmonize_labelled_spss_survey)
S3method(vec_ptype2,integer.retroharmonize_labelled_spss_survey)
S3method(vec_ptype2,retroharmonize_labelled_spss_survey.double)
S3method(vec_ptype2,retroharmonize_labelled_spss_survey.integer)
S3method(vec_ptype2,retroharmonize_labelled_spss_survey.retroharmonize_labelled_spss_survey)
S3method(vec_ptype_abbr,retroharmonize_labelled_spss_survey)
S3method(vec_ptype_full,retroharmonize_labelled_spss_survey)
S3method(weighted.mean,retroharmonize_labelled_spss_survey)
export("%>%")
export(as_character)
export(as_factor)
export(as_labelled_spss_survey)
export(as_numeric)
export(codebook_surveys_create)
export(codebook_waves_create)
export(collect_na_labels)
export(collect_val_labels)
export(concatenate)
export(create_codebook)
export(crosswalk)
export(crosswalk_surveys)
export(crosswalk_table_create)
export(document_survey_item)
export(document_surveys)
export(document_waves)
export(harmonize_na_values)
export(harmonize_survey_values)
export(harmonize_survey_variables)
export(harmonize_values)
export(harmonize_var_names)
export(harmonize_waves)
export(here)
export(is.crosswalk_table)
export(is.labelled_spss_survey)
export(is.na_range_to_values)
export(is.survey)
export(is.survey_df)
export(label_normalize)
export(labelled_spss_survey)
export(merge_surveys)
export(merge_waves)
export(metadata_create)
export(metadata_survey_create)
export(na_range_to_values)
export(pull_survey)
export(read.csv)
export(read_csv)
export(read_dta)
export(read_rds)
export(read_spss)
export(read_surveys)
export(subset_save_surveys)
export(subset_surveys)
export(subset_waves)
export(survey)
export(survey_df)
export(val_label_normalize)
export(var_label_normalize)
import(rlang)
import(vctrs)
importFrom(assertthat,assert_that)
importFrom(cli,cat_line)
importFrom(dataset,'identifier<-')
importFrom(dataset,datacite)
importFrom(dataset,dataset_df)
importFrom(dataset,defined)
importFrom(dataset,dublincore)
importFrom(dataset,is.dataset_df)
importFrom(dataset,subject_create)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,any_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,distinct)
importFrom(dplyr,distinct_all)
importFrom(dplyr,filter)
importFrom(dplyr,full_join)
importFrom(dplyr,group_by)
importFrom(dplyr,if_else)
importFrom(dplyr,inner_join)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_all)
importFrom(dplyr,pull)
importFrom(dplyr,select)
importFrom(dplyr,tally)
importFrom(dplyr,ungroup)
importFrom(fs,dir_exists)
importFrom(fs,file_exists)
importFrom(fs,is_file)
importFrom(fs,path_ext)
importFrom(fs,path_ext_remove)
importFrom(fs,path_file)
importFrom(glue,glue)
importFrom(haven,format_tagged_na)
importFrom(haven,is.labelled)
importFrom(haven,labelled)
importFrom(haven,labelled_spss)
importFrom(haven,read_dta)
importFrom(haven,read_spss)
importFrom(here,here)
importFrom(labelled,"var_label<-")
importFrom(labelled,`var_label<-`)
importFrom(labelled,labelled)
importFrom(labelled,na_range)
importFrom(labelled,na_values)
importFrom(labelled,to_character)
importFrom(labelled,to_labelled)
importFrom(labelled,val_labels)
importFrom(labelled,var_label)
importFrom(magrittr,"%>%")
importFrom(purrr,map)
importFrom(purrr,reduce)
importFrom(purrr,safely)
importFrom(purrr,set_names)
importFrom(rlang,.data)
importFrom(rlang,set_names)
importFrom(snakecase,to_snake_case)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stats,weighted.mean)
importFrom(stringr,str_extract)
importFrom(tibble,as_tibble)
importFrom(tibble,deframe)
importFrom(tibble,rowid_to_column)
importFrom(tibble,tibble)
importFrom(tidyr,nest)
importFrom(tidyr,unnest)
importFrom(tidyr,unnest_longer)
importFrom(tidyselect,all_of)
importFrom(tidyselect,everything)
importFrom(utils,bibentry)
importFrom(utils,head)
importFrom(utils,object.size)
importFrom(utils,person)
importFrom(utils,read.csv)
importFrom(vctrs,vec_data)
