#' @title Data Input
#'
#' @description See \code{utils::\link[utils:read.table]{read.csv}} for details.
#'
#' @name read.csv
#' @rdname read.csv
#' @keywords internal
#' @export
#' @importFrom utils read.csv
NULL
