#' @title Here
#'
#' @description A utility to make sure the system files of the package and other
#' files are always found, regardless if they are in an example or
#' vignette context.
#'
#' @details See \code{here::\link[here:here]{here}} for details.
#'
#' @name here
#' @keywords internal
#' @export
#' @importFrom here here
#' @examples
#' dir(here("inst", "examples"))
NULL
