# print method works

    <labelled_spss_survey<double>[3]>: Question text
    1 2 9
    Missing values: 9
    See all attributes survey1_name, survey1_values, survey1_label [...], survey1_na_values with attributes(x)

# pillar shaft works

    <pillar_ornament>
    # A tibble: 10 x 1
       v1             
       <retroh_int>   
     1  1 [Good]      
     2  2             
     3  3             
     4  4             
     5  5             
     6  6             
     7  7             
     8  8 [Bad]       
     9  9 (NA)        
    10 10 (NA)        

# pillar display works

    <pillar>
    <retroh_int>
     1 [Good]   
     2          
     3          
     4          
     5          
     6          
     7          
     8 [Bad]    
     9 (NA)     
    10 (NA)     

