% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/labelled_spss_survey-vctrs.R
\name{labelled_spss_survey_vctrs}
\alias{labelled_spss_survey_vctrs}
\alias{vec_ptype2.retroharmonize_labelled_spss_survey.double}
\alias{vec_ptype2.double.retroharmonize_labelled_spss_survey}
\alias{vec_ptype2.integer.retroharmonize_labelled_spss_survey}
\alias{vec_ptype2.retroharmonize_labelled_spss_survey.integer}
\alias{vec_cast.double.retroharmonize_labelled_spss_survey}
\alias{vec_cast.integer.retroharmonize_labelled_spss_survey}
\alias{vec_cast.character.retroharmonize_labelled_spss_survey}
\title{vctrs type and casting methods for labelled survey vectors}
\usage{
\method{vec_ptype2}{retroharmonize_labelled_spss_survey.double}(x, y, ...)

\method{vec_ptype2}{double.retroharmonize_labelled_spss_survey}(x, y, ...)

\method{vec_ptype2}{integer.retroharmonize_labelled_spss_survey}(x, y, ...)

\method{vec_ptype2}{retroharmonize_labelled_spss_survey.integer}(x, y, ...)

\method{vec_cast}{double.retroharmonize_labelled_spss_survey}(x, to, ...)

\method{vec_cast}{integer.retroharmonize_labelled_spss_survey}(x, to, ...)

\method{vec_cast}{character.retroharmonize_labelled_spss_survey}(x, to, ...)
}
\description{
These methods define how
\code{retroharmonize_labelled_spss_survey} objects interact with
base vectors and with each other in vctrs-based operations such as
concatenation, binding, and coercion.
}
\details{
They ensure that labelled survey vectors:
\itemize{
  \item combine safely with numeric vectors,
  \item cast consistently to base types,
  \item error on incompatible coercions.
}

These functions are part of the internal type system and are not
intended to be called directly by users.
}
\keyword{internal}
