% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-read_csv.R
\name{read.csv}
\alias{read.csv}
\title{Data Input}
\description{
See \code{utils::\link[utils:read.table]{read.csv}} for details.
}
\keyword{internal}
